@@ -27,12 +27,9 @@ use Test::More;
 use Test::Class;
 use Perl6::Pod::Test;
 use base qw( Test::Class Perl6::Pod::Test );
-use Perl6::Pod::To::Mem;
-use Perl6::Pod::To::XML;
 use Perl6::Pod::To::DocBook;
 use Perl6::Pod::To::XHTML;
 use XML::Flow;
-use XML::ExtOn ('create_pipe');
 
 sub testing_class {
     my $test = shift;
@@ -41,37 +38,15 @@ sub testing_class {
 }
 
 sub parse_to_latex {
-  my $test  =shift;
-  my ($text, @filters) = @_;
-  my $out = '';
-  my $to_mem = new TestSlide:: out_put => \$out;
-  my ( $p, $f ) = $test->make_parser( @filters, $to_mem );
-  $p->parse( \$text );
-  return wantarray ? ( $p, $f, $out ) : $out;
-
-}
-
-=head2 get_out4block BLOCKNAME TEXT
-
-return rendered out text
-=cut
-
-sub get_out4block {
-    my $t = shift;
-    my $blockname = shift;
-    my  ( $p, $f, $out ) = $t->parse_to_latex(@_);
-    return wantarray ? ($f, $f->{$blockname} ) : $f->{$blockname};
-}
-
-#overwrite Perl6::Pod::Test class
-sub make_parser {
-    my $self = shift;
-    my ( $p, $out_formatter )  = $self->SUPER::make_parser(@_);
-    #resgister
-#    my $use = $p->current_context->use;
-#    %$use = ( %$use, %{( NAME_BLOCKS )}); 
-    return wantarray ? ( $p, $out_formatter ) : $p;
-
+    my ( $text, %args) = @_;
+    my $out    = '';
+    open( my $fd, ">", \$out );
+    my $renderer = new Perl6::Pod::Slide::
+#      writer  => new Perl6::Pod::Writer( out => $fd, escape=>'xml' ),
+      out => $fd,
+        %args;
+    $renderer->parse( \$text, default_pod=>1 );
+    return wantarray ? (  $out, $renderer  ) : $out;
 }
 
 sub new_args { () }
